@@ -26,10 +26,18 @@
  */
 
 #include "avilib.h"
+#ifdef HAVE_CONFIG_H
 #include "../config.h"
+#else 
+#define PACKAGE "transcode"
+#define VERSION "0.6.10"
+#endif
 
 #define INFO_LIST
 
+#define DEBUG_ODML
+#undef DEBUG_ODML
+
 /* The following variable indicates the kind of error */
 
 long AVI_errno = 0;
@@ -99,15 +107,24 @@ static void long2str(unsigned char *dst, int n)
    dst[3] = (n>>24)&0xff;
 }
 
+#ifdef WORDS_BIGENDIAN
 static void short2str(unsigned char *dst, int n)
 {
    dst[0] = (n    )&0xff;
    dst[1] = (n>> 8)&0xff;
 }
+#endif
 
 /* Convert a string of 4 or 2 bytes to a number,
    also working on big endian machines */
 
+static unsigned long long str2ullong(unsigned char *str)
+{
+   unsigned long long r = (str[0] | (str[1]<<8) | (str[2]<<16) | (str[3]<<24));
+   unsigned long long s = (str[4] | (str[5]<<8) | (str[6]<<16) | (str[7]<<24));
+   return ((s<<32)&0xffffffff00000000ULL)|(r&0xffffffffULL);
+}
+
 static unsigned long str2ulong(unsigned char *str)
 {
    return ( str[0] | (str[1]<<8) | (str[2]<<16) | (str[3]<<24) );
@@ -117,6 +134,19 @@ static unsigned long str2ushort(unsigned char *str)
    return ( str[0] | (str[1]<<8) );
 }
 
+// bit 31 denotes a keyframe
+static unsigned long str2ulong_len (unsigned char *str)
+{
+   return str2ulong(str) & 0x7fffffff;
+}
+
+
+// if bit 31 is not 0, its a keyframe
+static unsigned long str2ulong_key (unsigned char *str)
+{
+   return (str2ulong(str) & 0x80000000)?0:0x10;
+}
+
 /* Calculate audio sample size from number of bits and number of channels.
    This may have to be adjusted for eg. 12 bits and stereo */
 
@@ -135,7 +165,8 @@ static int avi_sampsize(avi_t *AVI, int j)
 static int avi_add_chunk(avi_t *AVI, unsigned char *tag, unsigned char *data, int length)
 {
    unsigned char c[8];
-
+   char p=0;
+   
    /* Copy tag and length int c, so that we need only 1 write system call
       for these two values */
 
@@ -145,10 +176,9 @@ static int avi_add_chunk(avi_t *AVI, unsigned char *tag, unsigned char *data, in
    /* Output tag, length and data, restore previous position
       if the write fails */
 
-   length = PAD_EVEN(length);
-
    if( avi_write(AVI->fdes,c,8) != 8 ||
-       avi_write(AVI->fdes,data,length) != length )
+       avi_write(AVI->fdes,data,length) != length ||
+       avi_write(AVI->fdes,&p,length&1) != (length&1)) // if len is uneven, write a pad byte
    {
       lseek(AVI->fdes,AVI->pos,SEEK_SET);
       AVI_errno = AVI_ERR_WRITE;
@@ -157,7 +187,7 @@ static int avi_add_chunk(avi_t *AVI, unsigned char *tag, unsigned char *data, in
 
    /* Update file position */
 
-   AVI->pos += 8 + length;
+   AVI->pos += 8 + PAD_EVEN(length);
 
    //fprintf(stderr, "pos=%lu %s\n", AVI->pos, tag);
 
@@ -615,7 +645,7 @@ static int avi_parse_comments (int fd, char *buf, int space_left)
     }
 
     if ( !(data = malloc(st.st_size*sizeof(char)+1)) ) {
-	printf("malloc failed\n"); 
+	fprintf(stderr, "malloc failed\n"); 
 	return -1;
     }
 
@@ -869,17 +899,30 @@ static int avi_close_output_file(avi_t *AVI)
      
      //if (AVI->track[j].a_chans && AVI->track[j].audio_bytes)
        {
-	 unsigned long nBlockAlign;
+	 unsigned long nBlockAlign = 0;
+	 unsigned long avgbsec = 0;
+	 unsigned long scalerate = 0;
 	   
 	 sampsize = avi_sampsize(AVI, j);
 	 sampsize = AVI->track[j].a_fmt==0x1?sampsize*4:sampsize;
 
 	 nBlockAlign = (AVI->track[j].a_rate<32000)?576:1152;
 	 /*
-	 printf("XXX sampsize (%d) block (%ld) rate (%ld) audio_bytes (%ld) chunks(%ld)\n", 
-		 sampsize, nBlockAlign, AVI->track[j].a_rate, AVI->track[j].audio_bytes, AVI->track[j].audio_chunks );
+	 printf("XXX sampsize (%d) block (%ld) rate (%ld) audio_bytes (%ld) mp3rate(%ld,%ld)\n", 
+		 sampsize, nBlockAlign, AVI->track[j].a_rate, 
+		 (long int)AVI->track[j].audio_bytes, 
+		 1000*AVI->track[j].mp3rate/8, AVI->track[j].mp3rate);
 		 */
 	   
+	 if (AVI->track[j].a_fmt==0x1) {
+	     sampsize = (AVI->track[j].a_chans<2)?sampsize/2:sampsize;
+	     avgbsec = AVI->track[j].a_rate*sampsize/4;
+	     scalerate = AVI->track[j].a_rate*sampsize/4;
+	 } else  {
+	     avgbsec = 1000*AVI->track[j].mp3rate/8;
+	     scalerate = 1000*AVI->track[j].mp3rate/8;
+	 }
+
 	 OUT4CC ("LIST");
 	 OUTLONG(0);        /* Length of list in bytes, don't know yet */
 	 strl_start = nhb;  /* Store start position */
@@ -913,7 +956,7 @@ static int avi_close_output_file(avi_t *AVI)
 	     OUTLONG(0);                             /* Frame */
 	 } else {
 	     OUTLONG(sampsize/4);                    /* Scale */
-	     OUTLONG(1000*AVI->track[j].mp3rate/8);  /* Rate */
+	     OUTLONG(scalerate);  /* Rate */
 	     OUTLONG(0);                             /* Start */
 	     OUTLONG(4*AVI->track[j].audio_bytes/sampsize);   /* Length */
 	     OUTLONG(0);                             /* SuggestedBufferSize */
@@ -965,14 +1008,15 @@ static int avi_close_output_file(avi_t *AVI)
 	 
 	 } else {
 
-	     OUTLONG(16);                   /* # of bytes to follow */
+	     OUTLONG(18);                   /* # of bytes to follow */
 	     OUTSHRT(AVI->track[j].a_fmt);           /* Format */
 	     OUTSHRT(AVI->track[j].a_chans);         /* Number of channels */
 	     OUTLONG(AVI->track[j].a_rate);          /* SamplesPerSec */
 	     //ThOe/tibit
-	     OUTLONG(1000*AVI->track[j].mp3rate/8);
+	     OUTLONG(avgbsec);  /* Avg bytes/sec */
 	     OUTSHRT(sampsize/4);                    /* BlockAlign */
 	     OUTSHRT(AVI->track[j].a_bits);          /* BitsPerSample */
+	     OUTSHRT(0);                           /* cbSize */  
 
 	 }
 	 /* Finish stream list, i.e. put number of bytes in the list to proper pos */
@@ -1261,6 +1305,7 @@ int  AVI_get_comment_fd(avi_t *AVI)
 int AVI_close(avi_t *AVI)
 {
    int ret;
+   int j;
 
    /* If the file was open for writing, the header and index still have
       to be written */
@@ -1278,8 +1323,20 @@ int AVI_close(avi_t *AVI)
    close(AVI->fdes);
    if(AVI->idx) free(AVI->idx);
    if(AVI->video_index) free(AVI->video_index);
-   //FIXME
-   //if(AVI->audio_index) free(AVI->audio_index);
+   if(AVI->video_superindex) {
+       if(AVI->video_superindex->aIndex) free(AVI->video_superindex->aIndex);
+       free(AVI->video_superindex);
+   }
+
+   for (j=0; j<AVI->anum; j++) 
+   {
+       if(AVI->track[j].audio_index) free(AVI->track[j].audio_index);
+       if(AVI->track[j].audio_superindex) {
+	   if(AVI->track[j].audio_superindex->aIndex) free(AVI->track[j].audio_superindex->aIndex);
+	   free(AVI->track[j].audio_superindex);
+       }
+   }
+
    free(AVI);
    AVI=NULL;
 
@@ -1456,6 +1513,7 @@ int avi_parse_index_from_file(avi_t *AVI, char *filename)
     for (i=0; i<AVI_MAX_TRACKS; i++) aud_chunks[i] = 0;
     i=0;
 
+
     if (AVI->video_index)  // already have an index
 	return 0;
 
@@ -1522,7 +1580,7 @@ int avi_parse_index_from_file(avi_t *AVI, char *filename)
 
 	switch (i) {
 	    case 0: // video
-		AVI->video_index[vid_chunks].key = (off_t)key;
+		AVI->video_index[vid_chunks].key = (off_t)(key?0x10:0);
 		AVI->video_index[vid_chunks].pos = pos+8;
 		AVI->video_index[vid_chunks].len = len;
 		vid_chunks++;
@@ -1641,16 +1699,24 @@ int avi_parse_input_file(avi_t *AVI, int getIndex)
    {
       /* List tags are completly ignored */
 
+#ifdef DEBUG_ODML
+      printf("TAG %c%c%c%c\n", (hdrl_data+i)[0], (hdrl_data+i)[1], (hdrl_data+i)[2], (hdrl_data+i)[3]);
+#endif
+
       if(strncasecmp(hdrl_data+i,"LIST",4)==0) { i+= 12; continue; }
 
       n = str2ulong(hdrl_data+i+4);
       n = PAD_EVEN(n);
 
+
       /* Interpret the tag and its args */
 
       if(strncasecmp(hdrl_data+i,"strh",4)==0)
       {
          i += 8;
+#ifdef DEBUG_ODML
+	 printf("TAG   %c%c%c%c\n", (hdrl_data+i)[0], (hdrl_data+i)[1], (hdrl_data+i)[2], (hdrl_data+i)[3]);
+#endif
          if(strncasecmp(hdrl_data+i,"vids",4) == 0 && !vids_strh_seen)
          {
             memcpy(AVI->compressor,hdrl_data+i+4,4);
@@ -1689,10 +1755,20 @@ int avi_parse_input_file(avi_t *AVI, int getIndex)
 	   AVI->track[AVI->aptr].a_codech_off = header_offset + i;
 	   
          }
+         else if (strncasecmp (hdrl_data+i,"iavs",4) ==0 && ! auds_strh_seen) {
+	     fprintf(stderr, "AVILIB: error - DV AVI Type 1 no supported\n");
+	     return (-1);
+	 }
          else
             lasttag = 0;
          num_stream++;
       }
+      else if(strncasecmp(hdrl_data+i,"dmlh",4) == 0) {
+#ifdef DEBUG_ODML
+	 fprintf(stderr, "real number of frames %ld\n", str2ulong(hdrl_data+i+8));
+#endif
+	 i += 8;
+      }
       else if(strncasecmp(hdrl_data+i,"strf",4)==0)
       {
          i += 8;
@@ -1723,13 +1799,126 @@ int avi_parse_input_file(avi_t *AVI, int getIndex)
             AVI->track[AVI->aptr].a_bits  = str2ushort(hdrl_data+i+14);
 	    //            auds_strf_seen = 1;
          }
-         lasttag = 0;
       }
-      else
+      else if(strncasecmp(hdrl_data+i,"indx",4) == 0) {
+	 char *a;
+	 int j;
+
+	 if(lasttag == 1) // V I D E O
+	 { 
+
+	    a = hdrl_data+i;
+
+	    AVI->video_superindex = (avisuperindex_chunk *) malloc (sizeof (avisuperindex_chunk));
+	    memcpy (AVI->video_superindex->fcc, a, 4);             a += 4;
+	    AVI->video_superindex->dwSize = str2ulong(a);          a += 4;
+	    AVI->video_superindex->wLongsPerEntry = str2ushort(a); a += 2;
+	    AVI->video_superindex->bIndexSubType = *a;             a += 1;
+	    AVI->video_superindex->bIndexType = *a;                a += 1;
+	    AVI->video_superindex->nEntriesInUse = str2ulong(a);   a += 4;
+	    memcpy (AVI->video_superindex->dwChunkId, a, 4);       a += 4;
+
+	    // 3 * reserved
+	    a += 4; a += 4; a += 4;
+
+	    if (AVI->video_superindex->bIndexSubType != 0) {fprintf(stderr, "Invalid Header, bIndexSubType != 0\n"); }
+	    
+	    AVI->video_superindex->aIndex = 
+	       malloc (AVI->video_superindex->wLongsPerEntry * AVI->video_superindex->nEntriesInUse * sizeof (unsigned long));
+
+	    // position of ix## chunks
+	    for (j=0; j<AVI->video_superindex->nEntriesInUse; ++j) {
+	       AVI->video_superindex->aIndex[j].qwOffset = str2ullong (a);  a += 8;
+	       AVI->video_superindex->aIndex[j].dwSize = str2ulong (a);     a += 4;
+	       AVI->video_superindex->aIndex[j].dwDuration = str2ulong (a); a += 4;
+
+#ifdef DEBUG_ODML
+	       printf("[%d] 0x%llx 0x%lx %lu\n", j, AVI->video_superindex->aIndex[j].qwOffset,
+		     AVI->video_superindex->aIndex[j].dwSize, AVI->video_superindex->aIndex[j].dwDuration);
+#endif
+	    }
+
+
+#ifdef DEBUG_ODML
+	    printf("FOURCC \"%c%c%c%c\"\n", AVI->video_superindex->fcc[0], AVI->video_superindex->fcc[1], 
+		                            AVI->video_superindex->fcc[2], AVI->video_superindex->fcc[3]);
+	    printf("LEN \"%ld\"\n", AVI->video_superindex->dwSize);
+	    printf("wLongsPerEntry \"%d\"\n", AVI->video_superindex->wLongsPerEntry);
+	    printf("bIndexSubType \"%d\"\n", AVI->video_superindex->bIndexSubType);
+	    printf("bIndexType \"%d\"\n", AVI->video_superindex->bIndexType);
+	    printf("nEntriesInUse \"%ld\"\n", AVI->video_superindex->nEntriesInUse);
+	    printf("dwChunkId \"%c%c%c%c\"\n", AVI->video_superindex->dwChunkId[0], AVI->video_superindex->dwChunkId[1], 
+		                               AVI->video_superindex->dwChunkId[2], AVI->video_superindex->dwChunkId[3]);
+	    printf("--\n");
+#endif
+
+	    AVI->is_opendml = 1;
+
+	 }
+         else if(lasttag == 2) // A U D I O
+         {
+
+	    a = hdrl_data+i;
+
+	    AVI->track[AVI->aptr].audio_superindex = (avisuperindex_chunk *) malloc (sizeof (avisuperindex_chunk));
+	    memcpy (AVI->track[AVI->aptr].audio_superindex->fcc, a, 4);             a += 4;
+	    AVI->track[AVI->aptr].audio_superindex->dwSize = str2ulong(a);          a += 4;
+	    AVI->track[AVI->aptr].audio_superindex->wLongsPerEntry = str2ushort(a); a += 2;
+	    AVI->track[AVI->aptr].audio_superindex->bIndexSubType = *a;             a += 1;
+	    AVI->track[AVI->aptr].audio_superindex->bIndexType = *a;                a += 1;
+	    AVI->track[AVI->aptr].audio_superindex->nEntriesInUse = str2ulong(a);   a += 4;
+	    memcpy (AVI->track[AVI->aptr].audio_superindex->dwChunkId, a, 4);       a += 4;
+
+	    // 3 * reserved
+	    a += 4; a += 4; a += 4;
+
+	    if (AVI->track[AVI->aptr].audio_superindex->bIndexSubType != 0) {fprintf(stderr, "Invalid Header, bIndexSubType != 0\n"); }
+	    
+	    AVI->track[AVI->aptr].audio_superindex->aIndex = 
+	       malloc (AVI->track[AVI->aptr].audio_superindex->wLongsPerEntry * 
+		     AVI->track[AVI->aptr].audio_superindex->nEntriesInUse * sizeof (unsigned long));
+
+	    // position of ix## chunks
+	    for (j=0; j<AVI->track[AVI->aptr].audio_superindex->nEntriesInUse; ++j) {
+	       AVI->track[AVI->aptr].audio_superindex->aIndex[j].qwOffset = str2ullong (a);  a += 8;
+	       AVI->track[AVI->aptr].audio_superindex->aIndex[j].dwSize = str2ulong (a);     a += 4;
+	       AVI->track[AVI->aptr].audio_superindex->aIndex[j].dwDuration = str2ulong (a); a += 4;
+
+#ifdef DEBUG_ODML
+	       printf("[%d] 0x%llx 0x%lx %lu\n", j, AVI->track[AVI->aptr].audio_superindex->aIndex[j].qwOffset,
+		     AVI->track[AVI->aptr].audio_superindex->aIndex[j].dwSize, AVI->track[AVI->aptr].audio_superindex->aIndex[j].dwDuration);
+#endif
+	    }
+
+#ifdef DEBUG_ODML
+	    printf("FOURCC \"%c%c%c%c\"\n", AVI->track[AVI->aptr].audio_superindex->fcc[0], 
+		                            AVI->track[AVI->aptr].audio_superindex->fcc[1], 
+		                            AVI->track[AVI->aptr].audio_superindex->fcc[2], 
+					    AVI->track[AVI->aptr].audio_superindex->fcc[3]);
+	    printf("LEN \"%ld\"\n", AVI->track[AVI->aptr].audio_superindex->dwSize);
+	    printf("wLongsPerEntry \"%d\"\n", AVI->track[AVI->aptr].audio_superindex->wLongsPerEntry);
+	    printf("bIndexSubType \"%d\"\n", AVI->track[AVI->aptr].audio_superindex->bIndexSubType);
+	    printf("bIndexType \"%d\"\n", AVI->track[AVI->aptr].audio_superindex->bIndexType);
+	    printf("nEntriesInUse \"%ld\"\n", AVI->track[AVI->aptr].audio_superindex->nEntriesInUse);
+	    printf("dwChunkId \"%c%c%c%c\"\n", AVI->track[AVI->aptr].audio_superindex->dwChunkId[0], 
+		                               AVI->track[AVI->aptr].audio_superindex->dwChunkId[1], 
+		                               AVI->track[AVI->aptr].audio_superindex->dwChunkId[2], 
+					       AVI->track[AVI->aptr].audio_superindex->dwChunkId[3]);
+	    printf("--\n");
+#endif
+
+	 }
+	 i += 8;
+      }
+      else if(strncasecmp(hdrl_data+i,"JUNK",4) == 0) {
+	 i += 8;
+	 // do not reset lasttag
+      } else
       {
          i += 8;
          lasttag = 0;
       }
+      //printf("adding %ld bytes\n", (long int)n);
 
       i += n;
    }
@@ -1808,7 +1997,7 @@ int avi_parse_input_file(avi_t *AVI, int getIndex)
       /* idx_type remains 0 if neither of the two tests above succeeds */
    }
 
-   if(idx_type == 0)
+   if(idx_type == 0 && !AVI->is_opendml)
    {
       /* we must search through the file to get the index */
 
@@ -1844,6 +2033,146 @@ int avi_parse_input_file(avi_t *AVI, int getIndex)
       idx_type = 1;
    }
 
+   // ************************
+   // OPENDML
+   // ************************
+
+   // read extended index chunks
+   if (AVI->is_opendml) {
+      unsigned long long offset;
+      int hdrl_len = sizeof (avistdindex_chunk) - sizeof (avistdindex_entry *);
+      char *en, *chunk_start;
+      int k = 0, audtr = 0;
+      unsigned long nrEntries = 0;
+
+      AVI->video_index = NULL;
+
+      nvi = 0;
+      for(audtr=0; audtr<AVI->anum; ++audtr) nai[audtr] = tot[audtr] = 0; 
+
+      // ************************
+      // VIDEO
+      // ************************
+
+      for (j=0; j<AVI->video_superindex->nEntriesInUse; j++) {
+
+	 // read from file
+	 chunk_start = en = malloc (AVI->video_superindex->aIndex[j].dwSize);
+
+	 if (lseek(AVI->fdes, AVI->video_superindex->aIndex[j].qwOffset, SEEK_SET) == (off_t)-1) {
+	    fprintf(stderr, "(%s) cannot seek to 0x%llx\n", __FILE__, AVI->video_superindex->aIndex[j].qwOffset);
+	    return -1;
+	 }
+
+	 if (avi_read(AVI->fdes, en, AVI->video_superindex->aIndex[j].dwSize) <= 0) {
+	    fprintf(stderr, "(%s) cannot read from offset 0x%llx; broken (incomplete) file?\n", 
+		  __FILE__, AVI->video_superindex->aIndex[j].qwOffset);
+	    return -1;
+	 }
+
+	 nrEntries = str2ulong(en + 12);
+#ifdef DEBUG_ODML
+	 printf("[%d:0] Video nrEntries %ld\n", j, nrEntries);
+#endif
+	 offset = str2ullong(en + 20);
+
+	 // skip header
+	 en += hdrl_len;
+	 nvi += nrEntries;
+	 AVI->video_index = (video_index_entry *) realloc (AVI->video_index, nvi * sizeof (video_index_entry));
+
+	 while (k < nvi) {
+
+	    AVI->video_index[k].pos = offset + str2ulong(en); en += 4;
+	    AVI->video_index[k].len = str2ulong_len(en);
+	    AVI->video_index[k].key = str2ulong_key(en); en += 4;
+
+#ifdef DEBUG_ODML
+	    /*
+	    printf("[%d] POS 0x%llX len=%d key=%s offset (%llx) (%ld)\n", k, 
+		  AVI->video_index[k].pos, 
+		  (int)AVI->video_index[k].len, 
+		  AVI->video_index[k].key?"yes":"no ", offset, 
+		  AVI->video_superindex->aIndex[j].dwSize); 
+		  */
+#endif
+
+	    k++;
+	 }
+
+	 free(chunk_start);
+      }
+
+      AVI->video_frames = nvi;
+ 
+      // ************************
+      // AUDIO 
+      // ************************
+
+      for(audtr=0; audtr<AVI->anum; ++audtr) {
+
+	 k = 0;
+	 for (j=0; j<AVI->track[audtr].audio_superindex->nEntriesInUse; j++) {
+
+	    // read from file
+	    chunk_start = en = malloc (AVI->track[audtr].audio_superindex->aIndex[j].dwSize);
+
+	    if (lseek(AVI->fdes, AVI->track[audtr].audio_superindex->aIndex[j].qwOffset, SEEK_SET) == (off_t)-1) {
+	       fprintf(stderr, "(%s) cannot seek to 0x%llx\n", __FILE__, AVI->track[audtr].audio_superindex->aIndex[j].qwOffset);
+	       return -1;
+	    }
+
+	    if (avi_read(AVI->fdes, en, AVI->track[audtr].audio_superindex->aIndex[j].dwSize) <= 0) {
+	       fprintf(stderr, "(%s) cannot read from offset 0x%llx; broken (incomplete) file?\n", 
+		     __FILE__, AVI->track[audtr].audio_superindex->aIndex[j].qwOffset);
+	       return -1;
+	    }
+
+	    nrEntries = str2ulong(en + 12);
+#ifdef DEBUG_ODML
+	    printf("[%d:%d] Audio nrEntries %ld\n", j, audtr, nrEntries);
+#endif
+	    offset = str2ullong(en + 20);
+
+	    // skip header
+	    en += hdrl_len;
+	    nai[audtr] += nrEntries;
+	    AVI->track[audtr].audio_index = (audio_index_entry *) realloc (AVI->track[audtr].audio_index, nai[audtr] * sizeof (audio_index_entry));
+
+	    while (k < nai[audtr]) {
+
+	       AVI->track[audtr].audio_index[k].pos = offset + str2ulong(en); en += 4;
+	       AVI->track[audtr].audio_index[k].len = str2ulong_len(en); en += 4;
+	       AVI->track[audtr].audio_index[k].tot = tot[audtr];
+	       tot[audtr] += AVI->track[audtr].audio_index[k].len;
+
+#ifdef DEBUG_ODML
+	       /*
+		  printf("[%d] POS 0x%llX len=%d offset (%llx) (%ld)\n", k, 
+		  AVI->track[audtr].audio_index[k].pos, 
+		  (int)AVI->track[audtr].audio_index[k].len, 
+		  offset, AVI->track[audtr].audio_superindex->aIndex[j].dwSize); 
+		  */
+#endif
+
+	       ++k;
+	    }
+
+	    free(chunk_start);
+	 }
+	 
+	 AVI->track[audtr].audio_chunks = nai[audtr];
+	 AVI->track[audtr].audio_bytes = tot[audtr];
+      }
+   } // is opendml
+
+   else 
+
+   {
+   // ******************
+   // NO OPENDML
+   // ******************
+   
    /* Now generate the video index and audio index arrays */
 
    nvi = 0;
@@ -1858,8 +2187,7 @@ int avi_parse_input_file(avi_t *AVI, int getIndex)
    
    AVI->video_frames = nvi;
    for(j=0; j<AVI->anum; ++j) AVI->track[j].audio_chunks = nai[j];
-
-//   fprintf(stderr, "chunks = %ld %d %s\n", AVI->track[0].audio_chunks, AVI->anum, AVI->track[0].audio_tag);
+  
 
    if(AVI->video_frames==0) ERR_EXIT(AVI_ERR_NO_VIDS);
    AVI->video_index = (video_index_entry *) malloc(nvi*sizeof(video_index_entry));
@@ -1902,7 +2230,9 @@ int avi_parse_input_file(avi_t *AVI, int getIndex)
    
    
    for(j=0; j<AVI->anum; ++j) AVI->track[j].audio_bytes = tot[j];
-   
+
+   } // is no opendml
+
    /* Reposition the file */
    
    lseek(AVI->fdes,AVI->movi_start,SEEK_SET);
@@ -2356,11 +2686,21 @@ int AVI_read_wave_header( int fd, struct wave_header * wave )
 	AVI_errno = AVI_ERR_READ;
 	return -1;
     }
+    /*
+    fprintf(stderr, "RIFF: %c%c%c%c| (%d) (%d)\n", 
+	    wave->riff.id[0], wave->riff.id[1], wave->riff.id[2], wave->riff.id[3],
+	    sizeof (*wave), sizeof (struct wave_header));
+    fprintf(stderr, "WAVE: %c%c%c%c|\n", 
+	    wave->riff.wave_id[0], wave->riff.wave_id[1], wave->riff.wave_id[2], wave->riff.wave_id[3]);
+    fprintf(stderr, "fmt : %c%c%c%c|\n", 
+	    wave->format.id[0], wave->format.id[1], wave->format.id[2], wave->format.id[3]);
+    fprintf(stderr, "data: %c%c%c%c|\n", 
+	    wave->data.id[0], wave->data.id[1], wave->data.id[2], wave->data.id[3]);
+	    */
 
     if( strncasecmp(wave->riff.id     , "RIFF",4) != 0 ||
 	strncasecmp(wave->riff.wave_id, "WAVE",4) != 0 ||
-	strncasecmp(wave->format.id   , "fmt ",4) != 0 ||
-	strncasecmp(wave->data.id     , "data",4) != 0 )
+	strncasecmp(wave->format.id   , "fmt ",4) != 0 )
     {
 	AVI_errno = AVI_ERR_NO_AVI;
 	return -1;
