@@ -30,7 +30,7 @@
 #include "vid_aux.h"
 
 #define MOD_NAME    "export_dv.so"
-#define MOD_VERSION "v0.4 (2003-06-09)"
+#define MOD_VERSION "v0.5 (2003-07-24)"
 #define MOD_CODEC   "(video) Digital Video | (audio) MPEG/AC3/PCM"
 
 #define MOD_PRE dv
@@ -132,7 +132,7 @@ MOD_open
 
   if(param->flag == TC_VIDEO) {
 
-    AVI_set_video(vob->avifile_out, vob->ex_v_width, vob->ex_v_height, vob->fps, "DVSD");
+    AVI_set_video(vob->avifile_out, vob->ex_v_width, vob->ex_v_height, vob->ex_fps, "DVSD");
 
     if (vob->avi_comment_fd>0)
 	AVI_set_comment_fd(vob->avifile_out, vob->avi_comment_fd);
