@@ -237,6 +237,13 @@ MOD_open
   
   if(param->flag == TC_AUDIO) {
     
+      /*
+    if (!encoder) {
+      tc_warning("[export_dvraw] -y XXX,dvraw is not possible without the video");
+      tc_warning("[export_dvraw] export module also being dvraw");
+      return (TC_EXPORT_ERROR);
+    }
+    */
     chans = (vob->dm_chan != vob->a_chan) ? vob->dm_chan : vob->a_chan;
     //re-sampling only with -J resample possible
     rate = vob->a_rate;
@@ -269,8 +276,6 @@ MOD_open
 MOD_encode
 {
   
-  int i, j, ch;
-
   if(param->flag == TC_VIDEO) { 
     
     if(pass_through) {
@@ -333,7 +338,7 @@ MOD_encode
       //_dv_raw_insert_audio(target, &audio, encoder->isPAL);
       
       //FIXME: need to switch to "dv_encode_full_audio" only
-      audio_bufs[0] = param->buffer;
+      audio_bufs[0] = (uint16_t *)param->buffer;
       dv_encode_full_audio(encoder, audio_bufs, chans, rate, target);
 
 #else    
