@@ -72,6 +72,7 @@
  * Transcode module binding functions and strings
  ****************************************************************************/
 
+#define NAME        "xvid2"
 #define MOD_NAME    "export_xvid2.so"
 #define MOD_VERSION "v0.3.10 (2003-07-30)"
 #define MOD_CODEC   "(video) XviD 0.9.x (aka API 2.1 series)  | (audio) MPEG/AC3/PCM"
@@ -82,6 +83,8 @@
  * Local data
  ****************************************************************************/
 
+extern char* tc_config_dir;
+
 static int VbrMode = 0;
 static int encode_fields = 0;
 static avi_t *avifile = NULL;
@@ -172,17 +175,19 @@ MOD_init
 			(vob->ex_fps * vob->ex_v_width * vob->ex_v_height);
     
 		if((buffer = malloc(BUFFER_SIZE))==NULL) {
-			perror("out of memory");
+			perror("["NAME"] out of memory");
 			return(TC_EXPORT_ERROR); 
 		} else {
 			memset(buffer, 0, BUFFER_SIZE);  
 		}
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After malloc\n", NAME);
 
 		/* Load the codec */
 		if(xvid2_init(vob->mod_path)<0) {
-			fprintf(stderr, "Failed to init XviD codec");
+			fprintf(stderr, "[%s] Failed to init XviD codec", NAME);
 			return(TC_EXPORT_ERROR); 
 		}
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After xvid2_init\n", NAME);
 
 		VbrMode = vob->divxmultipass;
 
@@ -193,6 +198,8 @@ MOD_init
 
 		/* Set VBR control defaults */
 		vbrSetDefaults(&vbr_state);
+		
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After vbrSetDefaults\n", NAME);
 
 		/* Read the config file or set defaults */
 		xvid_config(&global_init,
@@ -201,9 +208,12 @@ MOD_init
 			    &vbr_state,
 			    quality);
 
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After config\n", NAME);
 		/* Initialize XviD */
 		XviD_init(NULL, 0, &global_init, NULL);
 
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After XviD_init\n", NAME);
+
 		/* Set values for the unitialized members */
 		global_param.width  = vob->ex_v_width;
 		global_param.height = vob->ex_v_height;
@@ -222,6 +232,7 @@ MOD_init
 			/* Disabling rate-control for all vbr modes */
 			global_param.rc_bitrate = 0;
 		}
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After fps stuff\n", NAME);
 
 		/*
 		 * These settings are passed through the command line and are
@@ -259,10 +270,12 @@ MOD_init
 		xerr = XviD_encore(NULL, XVID_ENC_CREATE, &global_param, NULL);
 
 		if(xerr == XVID_ERR_FAIL) {
-			fprintf(stderr, "codec open error");
+			fprintf(stderr, "[%s] codec open error", NAME);
 			return(TC_EXPORT_ERROR); 
 		}
 
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After XviD_encore\n", NAME);
+
 		/* Here is our XviD handle which identify our instance */
 		XviD_encore_handle = global_param.handle;
     
@@ -324,6 +337,8 @@ MOD_init
 			break;
 		}
 
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After vbr stuff\n", NAME);
+
 		/* Prepare things for Hinted ME */
 		if(global_frame.general & (XVID_HINTEDME_SET|XVID_HINTEDME_GET)) {
 			char *rights = "rb";
@@ -338,14 +353,18 @@ MOD_init
 			/* Open the hint file */
 			hints_file = fopen(HINT_FILE, rights);
 			if(hints_file == NULL) {
-				fprintf(stderr, "Error opening input file %s\n", HINT_FILE);
+				fprintf(stderr, "[%s] Error opening input file %s\n", NAME, HINT_FILE);
 				return(TC_EXPORT_ERROR);
 			}
 		}
 
 		/* Init the vbr state */
-		if(vbrInit(&vbr_state) != 0)
+		if(vbrInit(&vbr_state) != 0) {
+			fprintf(stderr, "[%s] Error doing vbrInit\n", NAME);
 			return(TC_EXPORT_ERROR);
+		}
+
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After vbr state\n", NAME);
 
 		/* Print debug info if required */
 		if(verbose_flag & TC_DEBUG) {
@@ -361,6 +380,8 @@ MOD_init
 
 			if(VbrMode == 2) xvid_print_vbr(&vbr_state);
 		}
+
+		if (verbose & TC_DEBUG) fprintf(stderr, "[%s] After print config\n", NAME);
     
 		return(TC_EXPORT_OK);
 
@@ -635,7 +656,7 @@ MOD_stop
 static int xvid2_init(char *path)
 {
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__APPLE__)
 	const
 #endif    
 		char *error;
@@ -666,7 +687,8 @@ static int xvid2_init(char *path)
 	}
 
 	/* None of the modules were available */
-	fprintf(stderr, dlerror());
+	error = dlerror();
+	fprintf(stderr, "[%s] %s\n", NAME, error);
 	return(-1);
 
  so_loaded:
@@ -679,7 +701,7 @@ static int xvid2_init(char *path)
     
 	/* Something went wrong */
 	if((error = dlerror()) != NULL)  {
-		fprintf(stderr, error);
+		fprintf(stderr, "[%s] (xvid_init) %s", NAME, error);
 		return(-1);
 	}
 
@@ -688,7 +710,7 @@ static int xvid2_init(char *path)
 
 	/* Something went wrong */
 	if((error = dlerror()) != NULL)  {
-		fprintf(stderr, error);
+		fprintf(stderr, "[%s] (xvid_encore) %s", NAME, error);
 		return(-1);
 	}
 
@@ -774,7 +796,13 @@ static int xvid_config(XVID_INIT_PARAM *einit,
 #ifdef DEVELOPER_USE
 
 	/* Check conf file existence */
-	if(stat(XVID_CONFIG_FILE, &statfile) == -1) {
+	if (tc_config_dir) {
+	    snprintf(buffer, 1024, "%s/%s", tc_config_dir, XVID_CONFIG_FILE);
+	} else {
+	    snprintf(buffer, 1024, "%s", XVID_CONFIG_FILE);
+	}
+
+	if(stat(buffer, &statfile) == -1) {
 
 		if(errno == ENOENT) {
 			char *home = getenv("HOME");
@@ -791,22 +819,21 @@ static int xvid_config(XVID_INIT_PARAM *einit,
 					return(0);
 				}
 			} else {
+				fprintf(stderr, "[%s] Unable to get HOME\n", NAME);
 				return(0);
 			}
 
 		} else {
-			fprintf(stderr, "Error: %s\nFalling back to hardcoded"
-				" defaults\n", strerror(errno));
+			fprintf(stderr, "[%s] Error: %s\nFalling back to hardcoded"
+				" defaults\n", NAME, strerror(errno));
 			return(0);
 		}
 
-	} else {
-		strcpy(buffer, XVID_CONFIG_FILE);
 	}
 
 	if(!S_ISREG(statfile.st_mode)) {
-		fprintf(stderr, "%s file is not a regular file ! Falling back"
-			" to defaults\n", buffer);
+		fprintf(stderr, "[%s] %s file is not a regular file ! Falling back"
+			" to defaults\n", NAME, buffer);
 		return(0);
 	}
 
@@ -815,7 +842,7 @@ static int xvid_config(XVID_INIT_PARAM *einit,
 	 * section
 	 */
 	if(( pRoot = cf_read( buffer ) ) == NULL ) {
-		fprintf(stderr, "Error reading configuration file\n");
+		fprintf(stderr, "[%s] Error reading configuration file\n", NAME);
 		return(0);
 	}
 
