@@ -65,7 +65,7 @@
  ****************************************************************************/
 
 #define MOD_NAME    "export_xvid4.so"
-#define MOD_VERSION "v0.0.2 (2003-07-30)"
+#define MOD_VERSION "v0.0.4 (2003-08-24)"
 #define MOD_CODEC  \
 "(video) XviD 1.0.x series (aka API 4.0) | (audio) MPEG/AC3/PCM"
 #define MOD_PRE xvid4_ 
@@ -79,6 +79,8 @@
  * Local data
  ****************************************************************************/
 
+extern char* tc_config_dir;
+
 /* Temporary audio/video buffer */
 static int verbose_flag = TC_QUIET;
 static int capability_flag = TC_CAP_PCM |
@@ -150,6 +152,7 @@ typedef struct _xvid_transcode_module_t
 	int cfg_vhq;
 	int cfg_motion;
 	int cfg_stats;
+	int cfg_greyscale;
 
 	/* MPEG4 stream buffer */
 	int   stream_size;
@@ -639,6 +642,7 @@ static void read_config_file(xvid_transcode_module_t *mod)
 			{"hqacpred", &mod->cfg_hqacpred, CONF_TYPE_FLAG, 0, 0, 1, NULL},
 			{"frame_drop_ratio", &create->frame_drop_ratio, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
 			{"stats", &mod->cfg_stats, CONF_TYPE_FLAG, 0, 0, 1, NULL},
+			{"greyscale", &mod->cfg_greyscale, CONF_TYPE_FLAG, 0, 0, 1, NULL},
 
 			/* section [quantizer] */
 			{"quantizer", "Quantizer settings", CONF_TYPE_SECTION, 0, 0, 0, NULL},
@@ -676,7 +680,7 @@ static void read_config_file(xvid_transcode_module_t *mod)
 		};
 
 	/* Read the values */
-	module_read_config(NULL, MOD_NAME, "xvid4", complete_config);
+	module_read_config(NULL, MOD_NAME, "xvid4", complete_config, tc_config_dir);
 
 	/* Print the values */
 	if(verbose_flag & TC_DEBUG)
@@ -735,6 +739,9 @@ static void dispatch_settings(xvid_transcode_module_t *mod)
 	if(mod->cfg_stats)
 		frame->vol_flags |= XVID_VOL_EXTRASTATS;
 
+	if(mod->cfg_greyscale)
+		frame->vop_flags |= XVID_VOP_GREYSCALE;
+
 	if(mod->cfg_intra_matrix_file) {
 		frame->quant_intra_matrix = (unsigned char*)read_matrix(mod->cfg_intra_matrix_file);
 		if(frame->quant_intra_matrix != NULL) {
@@ -1134,7 +1141,7 @@ static void print_matrix(unsigned char *matrix)
 
 static int load_xvid(xvid_module_t *xvid, char *path)
 {
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__APPLE__)
 	const char *error;
 #else
 	char *error;
@@ -1186,6 +1193,8 @@ static int load_xvid(xvid_module_t *xvid, char *path)
 
 	if(xvid->global == NULL && (error = dlerror()) != NULL) {
 		fprintf(stderr, "[%s] Error loading symbol (%s)\n", MOD_NAME, error);
+		fprintf(stderr, "[%s] Library \"%s\" looks like an old version of libxvidcore\n", MOD_NAME, soname[i]);
+		fprintf(stderr, "[%s] You cannot use this module with this lib; maybe -y xvid2 works\n", MOD_NAME);
 		return(-1);
 	}
 
