@@ -1,6 +1,6 @@
 /* Map transcode configure defines to libavcodecs */
 
-#include "../config.h"
+#include "config.h"
 
 /* These come from our config.h */
 /* #define ARCH_PPC */
@@ -23,6 +23,7 @@
 #define CONFIG_DECODERS 1
 #define CONFIG_MPEGAUDIO_HP 1
 #define CONFIG_VIDEO4LINUX 1
+#define CONFIG_DV1394 1
 #define CONFIG_AUDIO_OSS 1
 #define CONFIG_NETWORK 1
 
