@@ -21,7 +21,7 @@
 */
 
 #define MOD_NAME    "filter_smartyuv.so"
-#define MOD_VERSION "0.0.2 (2003-08-04)"
+#define MOD_VERSION "0.1.2 (2003-08-28)"
 #define MOD_CAP     "Motion-adaptive deinterlacing"
 #define MOD_AUTHOR  "Tilmann Bitterberg"
 
@@ -45,6 +45,21 @@
 #include "framebuffer.h"
 #include "optstr.h"
 
+//#undef HAVE_MMX
+
+// mmx gives a speedup of about 3 fps
+// when running without highq, mmx gives 12 fps
+
+#ifdef HAVE_MMX
+# include "mmx.h"
+#endif
+
+#ifndef HAVE_MMX
+# define emms() do{}while(0)
+#endif
+
+#define rdtscll(val) __asm__ __volatile__("rdtsc" : "=A" (val))
+
 static vob_t *vob=NULL;
 
 ///////////////////////////////////////////////////////////////////////////
@@ -105,7 +120,7 @@ static void help_optstr(void)
 {
    printf ("[%s] (%s) help\n", MOD_NAME, MOD_CAP);
    printf ("* Overview\n");
-   printf ("   New filter smartyuv. This filter is basically a rewrite of the\n");
+   printf ("   This filter is basically a rewrite of the\n");
    printf ("   smartdeinter filter by Donald Graft (without advanced processing\n");
    printf ("   options) for YUV mode only. Its faster than using the smartdeinter\n");
    printf ("   in YUV mode and is also tuned with its threshold settings for YUV\n");
@@ -123,9 +138,9 @@ static void help_optstr(void)
    printf ("   scenechanges go by unnoticed, lower the scene threshold. You can\n");
    printf ("   completly disable chroma processing with the doChroma=0 option.\n");
    printf ("   Here is a sample commandline\n");
-   printf ("   -J smartyuv=hiqhq=1:diffmode=2:cubic=1:Blend=1:chromathres=4:threshold=8:doChroma=1\n");
+   printf ("   -J smartyuv=highq=1:diffmode=2:cubic=1:Blend=1:chromathres=4:threshold=8:doChroma=1\n");
    printf ("* Options\n");
-   printf ("  'motionOnly' Show motion areas only (0=off, 1=on) [1]\n");
+   printf ("  'motionOnly' Show motion areas only (0=off, 1=on) [0]\n");
    printf ("    'diffmode' Motion Detection (0=frame, 1=field, 2=both) [0]\n");
    printf ("   'threshold' Motion Threshold (luma) (0-255) [14]\n");
    printf (" 'chromathres' Motion Threshold (chroma) (0-255) [7]\n");
@@ -138,19 +153,162 @@ static void help_optstr(void)
 
 }
 
+static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int height)
+{
+    int sum, x, y;
+    uint8_t  *m, *fmoving, *moving, *p;
+    int w4 = width+4;
+    int can_use_mmx = !(width%4);
+
+    // Erode.
+    fmoving = _fmoving;
+    moving = _moving;
+    p = moving - 2*w4 -2;
+
+    for (y = 0; y < height; y++)
+    {
+#ifdef HAVE_MMX
+	/*
+	 * The motion map as either 1 or 0.
+	 * moving[x] is the current position.
+	 * to decide if fmoving[x] should be 1, we need to sum up all 24 values.
+	 * Because of mmx, we can do that also with the next 3 positions since
+	 * the values are read in memory anyway.
+	 */
+
+	if (can_use_mmx) {
+	    for (x = 0; x < width; x+=4)
+	    {
+		uint8_t  res[8];
+
+		memcpy(fmoving, moving, 4);
+
+		m = p;
+
+		movq_m2r   (*m, mm0); m += w4;
+		paddusb_m2r(*m, mm0); m += w4;
+		paddusb_m2r(*m, mm0); m += w4;
+		paddusb_m2r(*m, mm0); m += w4;
+		paddusb_m2r(*m, mm0);
+
+		movq_r2m(mm0, *res);
+
+		if (*moving++) {
+		    res[0]+=res[1];
+		    res[0]+=res[2];
+		    res[0]+=res[3];
+		    res[0]+=res[4];
+		    *fmoving = (res[0] > 7);
+		}
+		fmoving++;
+
+		if (*moving++) {
+		    res[1]+=res[2];
+		    res[1]+=res[3];
+		    res[1]+=res[4];
+		    res[1]+=res[5];
+		    *fmoving = (res[1] > 7);
+		}
+		fmoving++;
+
+		if (*moving++) {
+		    res[2]+=res[3];
+		    res[2]+=res[4];
+		    res[2]+=res[5];
+		    res[2]+=res[6];
+		    *fmoving = (res[2] > 7);
+		}
+		fmoving++;
+
+		if (*moving++) {
+		    res[3]+=res[4];
+		    res[3]+=res[5];
+		    res[3]+=res[6];
+		    res[3]+=res[7];
+		    *fmoving = (res[3] > 7);
+		}
+		fmoving++;
+
+		p += 4;
+
+	    }
+	    fmoving += 4;
+	    moving += 4;
+	    p += 4;
+	} else 
+#endif
+	{
+	    for (x = 0; x < width; x++)
+	    {
+
+		if (!(fmoving[x] = moving[x]) )
+		    continue;
+
+		m = moving + x - 2*w4 -2;
+		sum = 1;
+
+		//sum += m[0] + m[1] + m[2] + m[3] + m[4];
+		//max sum is 25 or better 1<<25
+		sum <<= m[0]; sum <<= m[1]; sum <<= m[2]; sum <<= m[3]; sum <<= m[4];
+		m += w4;
+		sum <<= m[0]; sum <<= m[1]; sum <<= m[2]; sum <<= m[3]; sum <<= m[4];
+		m += w4;
+		sum <<= m[0]; sum <<= m[1]; sum <<= m[2]; sum <<= m[3]; sum <<= m[4];
+		m += w4;
+		sum <<= m[0]; sum <<= m[1]; sum <<= m[2]; sum <<= m[3]; sum <<= m[4];
+		m += w4;
+		sum <<= m[0]; sum <<= m[1]; sum <<= m[2]; sum <<= m[3]; sum <<= m[4];
+
+		// check if the only bit set has an index of 8 or greater (threshold is 7)
+		fmoving[x] = (sum > 128);
+	    }
+	    fmoving += w4;
+	    moving += w4;
+
+	} // else can use mmx
+
+    }
+    emms();
+
+
+    // Dilate.
+    fmoving = _fmoving;
+    moving = _moving;
+    for (y = 0; y < height; y++)
+    {
+	for (x = 0; x < width; x++)
+	{
+	    if ((moving[x] = fmoving[x])) {
+
+		m = moving + x - 2*w4 -2;
+
+		memset(m, 1, 5);
+		m += w4;
+		memset(m, 1, 5);
+		m += w4;
+		memset(m, 1, 5);
+		m += w4;
+		memset(m, 1, 5);
+		m += w4;
+		memset(m, 1, 5);
+	    }
+	}
+	moving += w4;
+	fmoving += w4;
+    }
+}
 static void inline Blendline_c (uint8_t *dst, uint8_t *src, uint8_t *srcminus, uint8_t *srcplus, 
 	                 uint8_t *moving, uint8_t *movingminus, uint8_t *movingplus, const int w, const int scenechange)
 {
     int	x=0;
 
-    x = 0;
     do {
-	if (!(movingminus[x] | moving[x] | movingplus[x]) && !scenechange)
-	    dst[x] = src[x];
-	else
-	{
+	if (movingminus[x] | moving[x] | movingplus[x] | scenechange)
 	    /* Blend fields. */
 	    dst[x] = ((src[x]>>1) + (srcminus[x]>>2) + (srcplus[x]>>2)) & 0xff;
+	else
+	{
+	    dst[x] = src[x];
 	}
     } while(++x < w);
 }
@@ -175,18 +333,18 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 	char			*src, *dst, *srcminus=NULL, *srcplus, *srcminusminus=NULL, *srcplusplus=NULL;
 	unsigned char		*moving, *movingminus, *movingplus;
-	unsigned char		*fmoving, *mm, *fm;
+	unsigned char		*fmoving;
 	char    		*prev;
 	int			scenechange=0;
-	long			count;
+	long			count=0;
 	int			x, y;
-	int			nextValue, prevValue, luma, luman, lumap, T;
-	int 			p0, p1, p2;
+	int			luma, luman, lumap, T;
+	int 			p1, p2;
 	int 			rp, rn, rpp, rnn, R;
-	unsigned char		frMotion, fiMotion;
+	unsigned char		fiMotion;
 	int			cubic = mfd->cubic;
 	static int 		counter=0;
-	int                     msize;
+	const int		can_use_mmx = !(w%8); // width must a multiple of 8
 
 
 	char * dst_buf;
@@ -199,39 +357,258 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	/* Not much deinterlacing to do if there aren't at least 2 lines. */
 	if (h < 2) return;
 
-	count = 0;
+	/* Skip first and last lines, they'll get a free ride. */
+	src = src_buf + srcpitch;
+	srcminus = src - srcpitch;
+	srcplus = src + srcpitch;
+	moving = _moving + w+4;
+	prev = _prev + w;
+
 	if (mfd->diffmode == FRAME_ONLY || mfd->diffmode == FRAME_AND_FIELD)
 	{
-		/* Skip first and last lines, they'll get a free ride. */
-		src = src_buf + srcpitch;
-		srcminus = src - srcpitch;
-		prev = _prev + w;
-		moving = _moving + w+4;
 		if (mfd->diffmode == FRAME_ONLY) {
+
+#ifdef HAVE_MMX
+		  if (can_use_mmx) {
+
+		    uint64_t mask1 = 0x00FF00FF00FF00FFULL;
+
+		    uint64_t thres = (_threshold<<16) | (_threshold);
+		    thres = (thres << 32) | (thres);
+
+		    movq_m2r (mask1, mm6);
+		    movq_m2r (thres, mm5);        // thres -> mm6
+
+		    count = 0;
 		    for (y = 1; y < hminus1; y++)
 		    {
-			x = 0;
-			do
-			{
+			for (x=0; x<w; x+=4) {
+
+			    movd_m2r (*src, mm0);         // a b c d 0 0 0 0
+
+			    punpcklbw_r2r (mm0, mm0);     // a a b b c c d d
+			    pand_r2r (mm6, mm0);          // 0 a 0 b 0 c 0 d
+
+			    movd_m2r(*prev, mm1);         // e f g h 0 0 0 0
+
+			    punpcklbw_r2r (mm1, mm1);     // e e f f g g h h
+			    pand_r2r (mm6, mm1);          // 0 e 0 f 0 g 0 h
+
+			    psubsw_r2r(mm1, mm0);         // mm0 = mm0 - mm1; !!
+
+			    movq_r2r(mm0, mm3);
+
+			    // abs()
+			    psraw_i2r(15, mm3);
+			    pxor_r2r(mm3, mm0);
+			    psubw_r2r(mm3, mm0);
+
+			    // compare if greater than thres
+			    pcmpgtw_r2r(mm5, mm0);
+
+			    // norm
+			    psrlw_i2r(15, mm0);
+			    // pack to bytes
+			    packuswb_r2r(mm0, mm0);
+
+			    // write to moving
+			    movd_r2m(mm0, *moving);
+
+			    memcpy(prev, src, 4);
+
+			    src+=4;
+			    prev+=4;
+
+			    count += *moving++;
+			    count += *moving++;
+			    count += *moving++;
+			    count += *moving++;
+
+			}
+
+			moving += 4;
+		    }
+		    emms();
+
+		  }  else  // cannot use mmx
+#endif
+		  {
+		    count = 0;
+		    for (y = 1; y < hminus1; y++)
+		    {
+			for (x=0; x<w; x++) {
 				// First check frame motion.
 				// Set the moving flag if the diff exceeds the configured
 				// threshold.
 				int luma = *src++&0xff;
-				int p0 = luma - (*(prev)&0xff);
-
-				*moving = ((ABS_u8(p0) > _threshold));
+				int p0 = luma - (*prev&0xff);
 
 				*prev++ = luma;
+				*moving = ((ABS_u8(p0) > _threshold));
+
 				/* Keep a count of the number of moving pixels for the
 				   scene change detection. */
 				count += *moving++;
-			} while(++x < w);
+				
+			}
 
 			srcminus += srcpitch;
 			moving += 4;
 		    }
+		  } // cannot use mmx
+
 		} else if (mfd->diffmode == FRAME_AND_FIELD) {
 
+#ifdef HAVE_MMX
+		  if (can_use_mmx) {
+
+		    uint64_t mask1 = 0x00FF00FF00FF00FFULL;
+
+		    uint64_t thres = (_threshold<<16) | (_threshold);
+		    thres = (thres << 32) | (thres);
+
+		    movq_m2r (mask1, mm6);
+		    movq_m2r (thres, mm5);        // thres -> mm6
+
+		    // ---------------------
+		    // create the motion map
+		    // ---------------------
+
+		    count = 0;
+		    for (y = 1; y < hminus1; y++)
+		    {
+			if (y & 1) { // odd lines
+
+			    for (x=0; x<w; x+=4) {
+
+				movd_m2r(*src, mm0);          // a b c d 0 0 0 0
+				movd_m2r(*srcminus, mm1); // e f g h 0 0 0 0
+				movd_m2r(*prev, mm2);
+
+				punpcklbw_r2r (mm0, mm0);     // a a b b c c d d
+				punpcklbw_r2r (mm1, mm1);     // e e f f g g h h
+				punpcklbw_r2r (mm2, mm2);
+				pand_r2r (mm6, mm0);          // 0 a 0 b 0 c 0 d
+				pand_r2r (mm6, mm1);          // 0 e 0 f 0 g 0 h
+				pand_r2r (mm6, mm2);
+
+				movq_r2r (mm0, mm7);          // save in mm7
+
+				psubsw_r2r(mm1, mm0);         // mm0 = mm0 - mm1; !!
+				psubsw_r2r(mm2, mm7);
+				movq_r2r(mm0, mm3);
+				movq_r2r(mm7, mm4);
+
+				// abs() ((mm0^(mm0>>15))-(mm0>>15))
+
+				psraw_i2r(15, mm3);
+				psraw_i2r(15, mm4);
+				pxor_r2r(mm3, mm0);
+				pxor_r2r(mm4, mm7);
+				psubw_r2r(mm3, mm0);
+				psubw_r2r(mm4, mm7);
+
+				pcmpgtw_r2r(mm5, mm0);     //compare if greater than thres
+				pcmpgtw_r2r(mm5, mm7);
+				psrlw_i2r(15, mm0);       // norm
+				psrlw_i2r(15, mm7);       // norm
+				packuswb_r2r(mm0, mm0);   // pack to bytes
+				packuswb_r2r(mm7, mm7);   // pack to bytes
+
+				// mm0: result first compare
+				// mm1-mm4: free
+				// mm5: threshold
+				// mm6: mask
+				// mm7: copy of src
+
+				pand_r2r(mm7, mm0);
+
+				// write to moving
+				movd_r2m(mm0, *moving);
+
+				memcpy(prev, src, 4);
+
+				src+=4;
+				prev+=4;
+				srcminus+=4;
+
+				count += *moving++;
+				count += *moving++;
+				count += *moving++;
+				count += *moving++;
+
+			    }
+
+			} else { // even lines
+
+			    for (x=0; x<w; x+=4) {
+				movd_m2r(*src, mm0);         // a b c d 0 0 0 0
+				movd_m2r(*(prev+w), mm1);    // e f g h 0 0 0 0
+				movd_m2r(*prev, mm2);
+
+				punpcklbw_r2r (mm0, mm0);     // a a b b c c d d
+				punpcklbw_r2r (mm1, mm1);     // e e f f g g h h
+				punpcklbw_r2r (mm2, mm2);
+				pand_r2r (mm6, mm0);          // 0 a 0 b 0 c 0 d
+				pand_r2r (mm6, mm1);          // 0 e 0 f 0 g 0 h
+				pand_r2r (mm6, mm2);
+
+				movq_r2r (mm0, mm7);          // save in mm7
+
+				psubsw_r2r(mm1, mm0);         // mm0 = mm0 - mm1; !!
+				psubsw_r2r(mm2, mm7);
+				movq_r2r(mm0, mm3);
+				movq_r2r(mm7, mm4);
+
+				// abs() ((mm0^(mm0>>15))-(mm0>>15))
+
+				psraw_i2r(15, mm3);
+				psraw_i2r(15, mm4);
+				pxor_r2r(mm3, mm0);
+				pxor_r2r(mm4, mm7);
+				psubw_r2r(mm3, mm0);
+				psubw_r2r(mm4, mm7);
+
+				pcmpgtw_r2r(mm5, mm0);     //compare if greater than thres
+				pcmpgtw_r2r(mm5, mm7);
+				psrlw_i2r(15, mm0);       // norm
+				psrlw_i2r(15, mm7);       // norm
+				packuswb_r2r(mm0, mm0);   // pack to bytes
+				packuswb_r2r(mm7, mm7);   // pack to bytes
+
+				// mm0: result first compare
+				// mm1-mm4: free
+				// mm5: threshold
+				// mm6: mask
+				// mm7: copy of src
+
+				pand_r2r(mm7, mm0);
+
+				// write to moving
+				movd_r2m(mm0, *moving);
+
+				memcpy(prev, src, 4);
+
+				src+=4;
+				prev+=4;
+
+				count += *moving++;
+				count += *moving++;
+				count += *moving++;
+				count += *moving++;
+
+			    }
+			    srcminus += srcpitch;
+
+			}
+			moving += 4;
+		    }
+
+		    emms();
+
+		  } else // cannot use mmx
+#endif
+		  {
 		    count = 0;
 		    for (y = 1; y < hminus1; y++)
 		    {
@@ -242,12 +619,11 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 				int luma = *src++&0xff;
 				int p0 = luma - (*(srcminus+x)&0xff);
-				int p1 = luma - (*(prev)&0xff);
+				int p1 = luma - (*prev&0xff);
 				/* 15:11 < GomGom> abs can be replaced by i^(i>>31)-(i>>31) */
 
-				*moving = ((ABS_u8(p0) > _threshold) & (ABS_u8(p1) > _threshold));
-
 				*prev++ = luma;
+				*moving = ((ABS_u8(p0) > _threshold) & (ABS_u8(p1) > _threshold));
 				count += *moving++;
 
 			    } while(++x < w);
@@ -258,11 +634,10 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 				int luma = *src++ & 0xff;
 				int p0 = luma - (*(prev+w)&0xff);
-				int p1 = luma - (*(prev)&0xff);
-
-				*moving = ((ABS_u8(p0) > _threshold) & (ABS_u8(p1) > _threshold));
+				int p1 = luma - (*prev&0xff);
 
 				*prev++ = luma;
+				*moving = ((ABS_u8(p0) > _threshold) & (ABS_u8(p1) > _threshold));
 				count += *moving++;
 
 			    } while(++x < w);
@@ -271,6 +646,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 			moving += 4;
 			srcminus += srcpitch;
 		    }
+		  }
 		}
 
 		/* Determine whether a scene change has occurred. */
@@ -278,7 +654,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		else scenechange = 0;
 
 		if (scenechange && mfd->verbose) 
-		    printf("[%s] Scenechange at %6d (%6d moving pixels)\n", MOD_NAME, counter, count);
+		    printf("[%s] Scenechange at %6d (%6ld moving pixels)\n", MOD_NAME, counter, count);
 		/*
 		printf("Frame (%04d) count (%8ld) sc (%d) calc (%02ld)\n", 
 				counter, count, scenechange, (100 * count) / (h * w));
@@ -288,148 +664,20 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		/* Perform a denoising of the motion map if enabled. */
 		if (!scenechange && mfd->highq)
 		{
-#if 0
-			int xlo, xhi, ylo, yhi;
-			int u, v;
-			int N = DENOISE_DIAMETER;
-			int Nover2 = N/2;
-			int sum;
-			unsigned char *m;
+		    //uint64_t before = 0;
+		    //uint64_t after = 0;
+		    //rdtscll(before);
 
-			// Erode.
-			fmoving = _fmoving;
-			for (y = 0; y < h; y++)
-			{
-				for (x = 0; x < w; x++)
-				{
-					if (!((_moving + y * w)[x]))
-					{
-						fmoving[x] = 0;	
-						continue;
-					}
-					xlo = x - Nover2; if (xlo < 0) xlo = 0;
-					xhi = x + Nover2; if (xhi >= w) xhi = wminus1;
-					ylo = y - Nover2; if (ylo < 0) ylo = 0;
-					yhi = y + Nover2; if (yhi >= h) yhi = hminus1;
-					m = _moving + ylo * w;
-					sum = 0;
-					for (u = ylo; u <= yhi; u++)
-					{
-						for (v = xlo; v <= xhi; v++)
-						{
-							sum += m[v];
-						}
-						m += w;
-					}
-					if (sum > DENOISE_THRESH)
-						fmoving[x] = 1;
-					else
-						fmoving[x] = 0;
-				}
-				fmoving += w;
-			}
-			// Dilate.
-			N = 5;
-			Nover2 = N/2;
-			moving = _moving;
-			for (y = 0; y < h; y++)
-			{
-				for (x = 0; x < w; x++)
-				{
-					if (!((_fmoving + y * w)[x]))
-					{
-						moving[x] = 0;	
-						continue;
-					}
-					xlo = x - Nover2; if (xlo < 0) xlo = 0;
-					xhi = x + Nover2; if (xhi >= w) xhi = wminus1;
-					ylo = y - Nover2; if (ylo < 0) ylo = 0;
-					yhi = y + Nover2; if (yhi >= h) yhi = hminus1;
-					m = _moving + ylo * w;
-					for (u = ylo; u <= yhi; u++)
-					{
-						for (v = xlo; v <= xhi; v++)
-						{
-							m[v] = 1;
-						}
-						m += w;
-					}
-				}
-				moving += w;
-			}
-#else
-			int sum;
-			uint8_t  *m;
-			
-			// this isn't exacly the same output like the original
-			// but just because the original was buggy -- tibit
+		    Erode_Dilate(_moving, _fmoving, w, h);
 
-
-			// Erode.
-			fmoving = _fmoving;
-			moving = _moving;
-			for (y = 0; y < h; y++)
-			{
-			    for (x = 0; x < w; x++)
-			    {
-
-				if (!(fmoving[x] = moving[x]) )
-				    continue;
-
-				m = _moving + (y-2)*(w+4) + (x-2);
-				sum = 0;
-
-				sum += m[0] + m[1] + m[2] + m[3] + m[4];
-				m += (w+4);
-				sum += m[0] + m[1] + m[2] + m[3] + m[4];
-				m += (w+4);
-				sum += m[0] + m[1] + m[2] + m[3] + m[4];
-				m += (w+4);
-				sum += m[0] + m[1] + m[2] + m[3] + m[4];
-				m += (w+4);
-				sum += m[0] + m[1] + m[2] + m[3] + m[4];
-
-				fmoving[x] = (sum > 7);
-			    }
-			    fmoving += (w+4);
-			    moving += (w+4);
-			}
-			// Dilate.
-			fmoving = _fmoving;
-			moving = _moving;
-			for (y = 0; y < h; y++)
-			{
-			    for (x = 0; x < w; x++)
-			    {
-				if (!(moving[x] = fmoving[x]) )
-				    continue;
-
-				m = _moving + (y-2)*(w+4) + (x-2);
-
-				memset(m, 1, 5);
-				m += (w+4);
-				memset(m, 1, 5);
-				m += (w+4);
-				memset(m, 1, 5);
-				m += (w+4);
-				memset(m, 1, 5);
-				m += (w+4);
-				memset(m, 1, 5);
-			    }
-			    moving += (w+4);
-			    fmoving += (w+4);
-			}
-#endif
+		    //rdtscll(after);
+		    //printf("%6d : %8lld\n", count, after-before);
 		}
 	}
-	else
-	{
+	if (mfd->diffmode == FIELD_ONLY) {
+
 		/* Field differencing only mode. */
 		T = _threshold * _threshold;
-		src = src_buf + srcpitch;
-		srcminus = src - srcpitch;
-		srcplus = src + srcpitch;
-		moving = _moving + w+4;
 		for (y = 1; y < hminus1; y++)
 		{
 			x = 0;
@@ -537,7 +785,10 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		}
 	}
 
+	// -----------------
 	// Render.
+	// -----------------
+
 	// The first line gets a free ride.
 	src = src_buf;
 	dst = dst_buf;
@@ -561,97 +812,57 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	/*
 	*/
 
-	for (y = 1; y < hminus1; y++)
+	if (mfd->motionOnly)
 	{
-		if (mfd->motionOnly)
+	    for (y = 1; y < hminus1; y++)
+	    {
+		if (mfd->Blend)
 		{
-			if (mfd->Blend)
-			{
-				x = 0;
-				do {
-					if (!(movingminus[x] | moving[x] | movingplus[x]) && !scenechange)
-						dst[x] = (clamp_f==clamp_Y)?BLACK_BYTE_Y:BLACK_BYTE_UV;
-					else
-					{	
-						/* Blend fields. */
-						dst[x] = (((src[x]&0xff)>>1) + ((srcminus[x]&0xff)>>2) + ((srcplus[x]&0xff)>>2))&0xff;
-					}
-				} while(++x < w);
-			}
+		    x = 0;
+		    do {
+			if (!(movingminus[x] | moving[x] | movingplus[x]) && !scenechange)
+			    dst[x] = (clamp_f==clamp_Y)?BLACK_BYTE_Y:BLACK_BYTE_UV;
 			else
-			{
-				x = 0;
-				do {
-					if (!(movingminus[x] | moving[x] | movingplus[x]) && !scenechange)
-						dst[x] = (clamp_f==clamp_Y)?BLACK_BYTE_Y:BLACK_BYTE_UV;
-					else if (y & 1)
-					{
-						if (cubic && (y > 2) && (y < hminus3))
-						{
-							rpp = (srcminusminus[x]) & 0xff;
-							rp =  (srcminus[x]) & 0xff;
-							rn =  (srcplus[x]) & 0xff;
-							rnn = (srcplusplus[x]) & 0xff;
-							R = (5 * (rp + rn) - (rpp + rnn)) >> 3;
-							/*
-							if (R>240) R = 240;
-							else if (R<16) R=16;
-							*/
-							dst[x] = clamp_f(R & 0xff)&0xff;
-						}
-						else
-						{
-							p1 = srcminus[x] &0xff;
-							p1 &= 0xfe;
-
-							p2 = srcplus[x] &0xff;
-							p2 &= 0xfe;
-							dst[x] = ((p1>>1) + (p2>>1)) &0xff;
-						}
-					}
-					else
-						dst[x] = src[x];
-				} while(++x < w);
+			{	
+			    /* Blend fields. */
+			    dst[x] = (((src[x]&0xff)>>1) + ((srcminus[x]&0xff)>>2) + ((srcplus[x]&0xff)>>2))&0xff;
 			}
+		    } while(++x < w);
 		}
-		else  /* Not motion only */
+		else
 		{
-			if (mfd->Blend)
+		    x = 0;
+		    do {
+			if (!(movingminus[x] | moving[x] | movingplus[x]) && !scenechange)
+			    dst[x] = (clamp_f==clamp_Y)?BLACK_BYTE_Y:BLACK_BYTE_UV;
+			else if (y & 1)
 			{
-			    Blendline_c (dst, src, srcminus, srcplus, moving, movingminus, movingplus, w, scenechange);
+			    if (cubic && (y > 2) && (y < hminus3))
+			    {
+				rpp = (srcminusminus[x]) & 0xff;
+				rp =  (srcminus[x]) & 0xff;
+				rn =  (srcplus[x]) & 0xff;
+				rnn = (srcplusplus[x]) & 0xff;
+				R = (5 * (rp + rn) - (rpp + rnn)) >> 3;
+				/*
+				   if (R>240) R = 240;
+				   else if (R<16) R=16;
+				   */
+				dst[x] = clamp_f(R & 0xff)&0xff;
+			    }
+			    else
+			    {
+				p1 = srcminus[x] &0xff;
+				p1 &= 0xfe;
+
+				p2 = srcplus[x] &0xff;
+				p2 &= 0xfe;
+				dst[x] = ((p1>>1) + (p2>>1)) &0xff;
+			    }
 			}
 			else
-			{
-				// Doing line interpolate. Thus, even lines are going through
-				// for moving and non-moving mode. Odd line pixels will be subject
-				// to the motion test.
-				if (y&1)
-				{
-					x = 0;
-					do {
-						if (!(movingminus[x] | moving[x] | movingplus[x]) && !scenechange)
-							dst[x] = src[x];
-						else
-						{
-							if (cubic && (y > 2) && (y < hminus3))
-							{
-								R = (5 * ((srcminus[x]&0xff) + (srcplus[x]&0xff)) 
-									- ((srcminusminus[x]&0xff) + (srcplusplus[x]&0xff))) >> 3;
-								dst[x] = clamp_f(R & 0xff)&0xff;
-							}
-							else
-							{
-								dst[x] = (((srcminus[x]&0xff)>>1) + ((srcplus[x]&0xff)>>1)) & 0xff;
-							}
-						}
-					} while(++x < w);
-				}
-				else
-				{
-					// Even line; pass it through.
-					memcpy(dst, src, w);
-				}
-			}
+			    dst[x] = src[x];
+		    } while(++x < w);
 		}
 		src = src + srcpitch;
 		srcminus = srcminus + srcpitch;
@@ -659,20 +870,169 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 		if (cubic)
 		{
-			srcminusminus = srcminusminus + srcpitch;
-			srcplusplus = srcplusplus + srcpitch;
+		    srcminusminus = srcminusminus + srcpitch;
+		    srcplusplus = srcplusplus + srcpitch;
 		}
 
 		dst = dst + dstpitch;
 		moving += (w+4);
 		movingminus += (w+4);
 		movingplus += (w+4);
+	    }
+	    // The last line gets a free ride.
+	    memcpy(dst, src, w);
+
+	    if (clamp_f == clamp_Y)
+		counter++;
+
+	    return;
+
 	}
+	
+	if (mfd->Blend)
+	{
+	    // linear blend, see Blendline_c for a plainC version
+	    for (y = 1; y < hminus1; y++)
+	    {
+#ifdef HAVE_MMX
+	      if (can_use_mmx) {
+
+		uint64_t scmask = (scenechange<<24) | (scenechange<<16) | (scenechange<<8) | scenechange;
+		scmask = (scmask << 32) | scmask;
+
+		pcmpeqw_r2r(mm4, mm4);
+		psrlw_i2r(9,mm4);
+		packuswb_r2r(mm4, mm4);         // build 0x7f7f7f7f7f7f7f7f
+
+		pcmpeqw_r2r(mm6, mm6);
+		psrlw_i2r(10,mm6);
+		packuswb_r2r(mm6, mm6);         // build 0x3f3f3f3f3f3f3f3f
+
+		for (x=0; x<w; x+=8) {
+
+		    movq_m2r(scmask, mm0);          // has a scenechange happend?
+
+		    pxor_r2r(mm5, mm5);             // clear mm5
+
+		    por_m2r (moving     [x], mm0);
+		    movq_m2r(src        [x], mm1);   // load src
+		    por_m2r (movingminus[x], mm0);   // motion detected?
+		    movq_m2r(src        [x-w], mm2);   // load srcminus
+		    por_m2r (movingplus [x], mm0);
+		    movq_m2r(src        [x+w], mm3);   // load srcplus
+
+		    movq_r2r (mm1, mm7);
+
+		    pcmpgtb_r2r(mm5, mm0);  // make FF out 1 and 0 out of 0
+
+		    pcmpeqw_r2r(mm5, mm5);  // make all ff's (recycle mm5)
+		    psubb_r2r  (mm0, mm5);  // inverse mask
+		    pand_r2r   (mm0, mm7); 
+		    pand_r2r   (mm5, mm1); 
+		    psrlw_i2r  (1,   mm7);
+
+		    pand_r2r   (mm4, mm7);  // clear highest bit
+		    por_r2r    (mm7, mm1);  // merge src>>1 and src together dependand on moving mask
+
+		    // mm0: mask, if 0 don't shift, if ff shift
+		    // mm1: complete src
+		    // mm2: srcminus
+		    // mm3: srcplus
+		    // mm4: 0x7f mask
+		    // mm5: free
+		    // mm6: 0x3f mask
+		    // mm7: free
+
+		    // handle srcm(inus) and srcp(lus)
+
+		    pand_r2r (mm0, mm2);
+		    pand_r2r (mm0, mm3);
+
+		    psrlw_i2r(2,   mm2);  // srcm>>2
+		    psrlw_i2r(2,   mm3);  // srcp>>2
+		    pand_r2r (mm6, mm2);  // clear highest two bits
+		    pand_r2r (mm6, mm3);
+
+		    paddusb_r2r (mm2, mm1);   // src>>1 + srcn>>2 + srcp>>2
+		    paddusb_r2r (mm3, mm1);
+
+		    movq_r2m(mm1, dst[x]);
+
+		}
+	      } else // cannot use mmx
+#endif
+	      {
+		Blendline_c (dst, src, srcminus, srcplus, moving, movingminus, movingplus, w, scenechange);
+	      }
+
+		src +=  srcpitch;
+		srcminus += srcpitch;
+		srcplus += srcpitch;
+
+		dst += dstpitch;
+		moving += (w+4);
+		movingminus += (w+4);
+		movingplus += (w+4);
+	    }
+	}
+	emms();
+
+	return;
+
+	// Doing line interpolate. Thus, even lines are going through
+	// for moving and non-moving mode. Odd line pixels will be subject
+	// to the motion test.
+
+	for (y = 1; y < hminus1; y++)
+	{
+	    if (y&1)
+	    {
+		x = 0;
+		do {
+		    if (movingminus[x] | moving[x] | movingplus[x] | scenechange)
+			if (cubic & (y > 2) & (y < hminus3))
+			{
+			    R = (5 * ((srcminus[x] & 0xff) + (srcplus[x] & 0xff)) 
+				    - ((srcminusminus[x] & 0xff) + (srcplusplus[x] & 0xff))) >> 3;
+			    dst[x] = clamp_f(R & 0xff)&0xff;
+			}
+			else
+			{
+			    dst[x] = (((srcminus[x]&0xff) >> 1) + ((srcplus[x]&0xff) >> 1)) & 0xff;
+			}
+		    else
+		    {
+			dst[x] = src[x];
+		    }
+		} while(++x < w);
+	    }
+	    else
+	    {
+		// Even line; pass it through.
+		memcpy(dst, src, w);
+	    }
+	    src +=  srcpitch;
+	    srcminus += srcpitch;
+	    srcplus += srcpitch;
+
+	    if (cubic)
+	    {
+		srcminusminus += srcpitch;
+		srcplusplus += srcpitch;
+	    }
+
+	    dst += dstpitch;
+	    moving += (w+4);
+	    movingminus += (w+4);
+	    movingplus += (w+4);
+	}
+
 	// The last line gets a free ride.
 	memcpy(dst, src, w);
 	if (clamp_f == clamp_Y)
 	    counter++;
 
+	return;
 }
 
 int tc_filter(vframe_list_t *ptr, char *options)
@@ -811,22 +1171,32 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	// o  Motion map creation
 	//      orig: 26.283.387 Cycles
 	//       now:  8.991.686 Cycles
+	//       mmx:  5.062.952
 	// o  Erode+dilate
 	//      orig: 55.847.077
 	//       now: 21.764.997
+	//  Erodemmx: 18.765.878
 	// o  Blending
 	//      orig: 8.162.287
 	//       now: 5.384.433
+	//       mmx: 4.569.875
+	//   new mmx: 3.656.537
 	// o  Cubic interpolation
 	//      orig: 7.487.338
 	//       now: 6.684.908
+	//      more: 3.554.580
 	//
 	// Overall improvement in transcode:
-	// 16.88 -> 24.72 frames per second for the test clip.
+	// 11.57 -> 22.78 frames per second for the test clip.
 	//
 
 	// filter init ok.
-	if(verbose) printf("[%s] %s %s\n", MOD_NAME, MOD_VERSION, MOD_CAP);
+
+	if(verbose) printf("[%s] "
+#ifdef HAVE_MMX
+		"(MMX) "
+#endif
+		"%s %s\n", MOD_NAME, MOD_VERSION, MOD_CAP);
 
 	return 0;
 
@@ -835,7 +1205,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
   if(ptr->tag & TC_FILTER_GET_CONFIG) {
       char buf[255];
-      optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VRYE", "1");
+      optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VYE", "1");
 
       sprintf (buf, "%d", mfd->motionOnly);
       optstr_param (options, "motionOnly", "Show motion areas only, blacking out static areas" ,"%d", buf, "0", "1");
@@ -891,6 +1261,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 ///////////////////////////////////////////////////////////////////////////
 
+  //if(ptr->tag & TC_PRE_S_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
   if(ptr->tag & TC_PRE_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
 	  
 	  int U  = ptr->v_width*ptr->v_height;
@@ -902,6 +1273,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	  memset(mfd->movingY,  0, msize);
 	  memset(mfd->fmovingY, 0, msize);
+	  /*
+	  */
 
 
 	  smartyuv_core(ptr->video_buf, mfd->buf, mfd->prevFrame, 
@@ -917,6 +1290,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	      memset(mfd->fmovingU, 0, msize);
 	      memset(mfd->movingV,  0, msize);
 	      memset(mfd->fmovingV, 0, msize);
+	      /*
+	      */
 
 	      smartyuv_core(ptr->video_buf+U, mfd->buf+U, mfd->prevFrame+U, 
 			  w2, h2, w2, w2,
