@@ -38,7 +38,8 @@
 #include <sys/ipc.h>
 #include <sys/shm.h>
 
-#ifdef __FreeBSD__ /* We don't have on_exit() */
+// FIXME: Use autoconf for this!!
+#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
 xv_display_t 	*xv_dpy_on_exit_hack = NULL;
 #endif
 
@@ -126,7 +127,7 @@ void xv_display_exit(xv_display_t *dv_dpy) {
   
   free(dv_dpy);
   dv_dpy = NULL;
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
   xv_dpy_on_exit_hack = NULL;
 #endif
 } // xv_display_exit
@@ -209,6 +210,10 @@ void xv_display_event (xv_display_t *dv_dpy)
 		sockmsg = TC_SOCK_PV_NONE;
 		preview_toggle_skip();
 		break;
+	    case TC_SOCK_PV_SAVE_JPG:
+		sockmsg = TC_SOCK_PV_NONE;
+		preview_grab_jpeg();
+		break;
 	    case TC_SOCK_PV_DISPLAY:
 		sockmsg = TC_SOCK_PV_NONE;
 		xv_pause=0;
@@ -339,6 +344,11 @@ void xv_display_event (xv_display_t *dv_dpy)
 	preview_toggle_skip();
 	break;
 
+      case XK_j:
+      case XK_J:
+	preview_grab_jpeg();
+	break;
+
 #if 0
       case XK_a:
       case XK_A:
@@ -632,7 +642,7 @@ static void xv_display_exit_handler(int code, void *arg)
   if(code && arg) xv_display_exit(arg);
 } // dv_display_exit_handler 
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
 static void
 xv_display_on_exit_hack_handler()
 {
@@ -684,12 +694,14 @@ int xv_display_init(xv_display_t *dv_dpy, int *argc, char ***argv, int width, in
     dv_dpy->pitches[2] = width / 2;
     break;
   }
+#if 0
   
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
   xv_dpy_on_exit_hack = dv_dpy;
   atexit(xv_display_on_exit_hack_handler);
 #else
   on_exit(xv_display_exit_handler, dv_dpy);
+#endif
 #endif
   
   return(0);
