@@ -373,7 +373,8 @@ long fileinfo(int fdes, int skip)
 
   // MOV
 
-  if(strncasecmp(buf+4,"moov", 4) ==0 || strncasecmp(buf+4,"mdat", 4) ==0) {
+  if(strncasecmp(buf+4,"moov", 4) ==0 || strncasecmp(buf+4,"mdat", 4) ==0 ||
+     strncasecmp(buf+4,"pnot", 4) ==0) {
     id = TC_MAGIC_MOV;
     goto exit;
   }
@@ -400,6 +401,14 @@ long fileinfo(int fdes, int skip)
     id = TC_MAGIC_XML;
     goto exit;
   }
+
+  // vncrec log file
+
+  if(strncasecmp(buf,"vncLog",6) ==0 ) {
+    id = TC_MAGIC_VNC;
+    goto exit;
+  }
+
  
   /* -------------------------------------------------------------------
    *
@@ -751,6 +760,7 @@ char *filetype(long magic)
   case TC_MAGIC_DVD_NTSC:     return("NTSC DVD image/device");
   case TC_MAGIC_YUV4MPEG:     return("YUV4MPEG stream");
   case TC_MAGIC_NUV:          return("NuppelVideo stream");
+  case TC_MAGIC_VNC:          return("VNCrec logfile");
 
   case TC_MAGIC_SOCKET:       return("network stream");
   case TC_MAGIC_V4L_AUDIO:    return("V4L audio device");
