@@ -46,6 +46,7 @@
 #define TC_CODEC_PS2                   0x00007002
 #define TC_CODEC_DIVX3                 0x000031B3
 #define TC_CODEC_MP42                  0x000031B4
+#define TC_CODEC_MP43                  0x000031B5
 #define TC_CODEC_DIVX4                 0x000041B6
 #define TC_CODEC_DIVX5                 0x000051B6
 #define TC_CODEC_XVID                  0x58766944
@@ -53,10 +54,21 @@
 #define TC_CODEC_MPG1                  0xA0000012
 #define TC_CODEC_SUB                   0xA0000011
 #define TC_CODEC_LAV                   0xFFFF0023
+#define TC_CODEC_THEORA                0x00001234
 #define TC_CODEC_VORBIS                0x0000FFFE
 #define TC_CODEC_LZO1                  0x0001FFFE
 #define TC_CODEC_RV10                  0x0002FFFE
-#define TC_CODEC_THEORA                0x00001234
+#define TC_CODEC_SVQ1                  0x0003FFFE
+#define TC_CODEC_SVQ3                  0x0004FFFE
+#define TC_CODEC_VP3                   0x0005FFFE
+#define TC_CODEC_4XM                   0x0006FFFE
+#define TC_CODEC_WMV1                  0x0007FFFE
+#define TC_CODEC_WMV2                  0x0008FFFE
+#define TC_CODEC_HFYU                  0x0009FFFE
+#define TC_CODEC_INDEO3                0x000AFFFE
+#define TC_CODEC_H263P                 0x000BFFFE
+#define TC_CODEC_H263I                 0x000CFFFE
+#define TC_CODEC_LZO2                  0x000DFFFE
 
 // file/device magic:
 #define TC_MAGIC_ERROR                 0xFFFFFFFF
@@ -75,6 +87,7 @@
 #define TC_MAGIC_LAV                   0x00000023
 #define TC_MAGIC_OGG                   0x00000024
 #define TC_MAGIC_AF6                   0x00000025
+#define TC_MAGIC_VNC                   0x00000026
 
 #define TC_MAGIC_VOB                   0x000001ba
 #define TC_MAGIC_SOCKET                0xFF00FF00
