@@ -54,9 +54,10 @@ void tcprobe_thread(info_t *ipipe);
 void extract_avi(info_t *ipipe);
 void decode_af6(info_t *ipipe);
 
-void decode_divx(info_t *ipipe);
+void decode_lavc(info_t *ipipe);
 void decode_xvid(info_t *ipipe);
 void decode_mov(info_t *ipipe);
+void decode_lzo(info_t *ipipe);
 
 void probe_yuv(info_t *ipipe);
 void probe_nuv(info_t *ipipe);
@@ -73,6 +74,7 @@ void probe_lav(info_t *ipipe);
 void probe_ogg(info_t *ipipe);
 void extract_ogm(info_t *ipipe);
 void decode_ogg(info_t *ipipe);
+void probe_vnc(info_t *ipipe);
 
 int scan_header_dv(char *buf);
 
