@@ -44,6 +44,7 @@ static char *std_module[] = {"null",
 			     "lav",
 			     "lzo",
 			     "ts",
+			     "vnc",
 			     "mplayer"
 };
 
@@ -64,6 +65,7 @@ enum _std_module {_null_,
 		  _lav_,
 		  _lzo_,
 		  _ts_,
+		  _vnc_,
 		  _theora_
 };
 
@@ -216,9 +218,9 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
   }
 
   if( !(*flag & TC_PROBE_NO_FRC)) {
-    if(info->frc>0) vob->im_frc = info->frc;
+    if(info->frc>0) { vob->im_frc = info->frc; }
   } else {
-    vob->fps = frc_table[vob->im_frc];
+    if (vob->fps == MIN_FPS) {vob->fps = frc_table[vob->im_frc];}
   }
 
   //check for additional attributes
@@ -470,6 +472,11 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
       preset |= TC_VIDEO;
       break;
 
+  case TC_MAGIC_VNC:
+      vob->vmod_probed=std_module[_vnc_];
+      preset |= TC_VIDEO;
+      break;
+
   case TC_MAGIC_DV_PAL:
   case TC_MAGIC_DV_NTSC:
 
@@ -610,6 +617,7 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
   case TC_CODEC_MJPG:
   case TC_CODEC_MPG1:
   case TC_CODEC_MP42:
+  case TC_CODEC_MP43:
   case TC_CODEC_RV10:
     vob->im_v_codec=CODEC_YUV;
 
@@ -626,6 +634,7 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
     break;
 
   case TC_CODEC_LZO1:
+  case TC_CODEC_LZO2:
 
     vob->im_v_codec=CODEC_YUV;
 
@@ -739,7 +748,10 @@ char *codec2str(int f)
     return("DivX;-)");
 
   case TC_CODEC_MP42:
-    return("MP42");
+    return("MSMPEG4 V2");
+
+  case TC_CODEC_MP43:
+    return("MSMPEG4 V3");
     
   case TC_CODEC_DIVX4:
     return("DivX");
