@@ -95,6 +95,7 @@
 #define ABITRATE       128
 #define AQUALITY         5
 #define AVBR             0
+#define AMODE            0
 
 //debug modes
 #define TC_QUIET         0
@@ -187,6 +188,7 @@
 #define TC_FRAME_IS_AC3         128
 #define TC_FRAME_IS_CLONED      256
 #define TC_FRAME_WAS_CLONED     512
+#define TC_FRAME_IS_OUT_OF_RANGE  1024
 
 //overwritten by cmd line parameter
 #define TC_PROBE_ERROR         -1
